@@ -1,7 +1,7 @@
-from movie import Movie, Trailer
-from person import Person
+from .movie import Movie, Trailer
+from .person import Person
 
-VERSION = (0, 5, 4)
+VERSION = (0, 5, 5)
 __version__ = '.'.join(map(str, VERSION))
 
-__all__ = ['Movie', 'Person', 'Trailer']
\ No newline at end of file
+__all__ = ['Movie', 'Person', 'Trailer']
